(function(exports) {
    var form = document.getElementById('form');
    var nameInput = document.getElementById('name');
    var id = document.getElementById('UID');
    var pass = document.getElementById('pass');
    var deleteButton = document.getElementById('delete');
    var saveButton = document.getElementById('save');

    var topList = document.getElementById('topList');
    var bottomList = document.getElementById('bottomList');
    var addComputerButton = document.getElementById('addComputer');

    var selected = 0;
    var devices = [];

    var back = document.getElementById('back');

    var setButtonState = function() {
        var settings = devices[selected];
        if (settings) {
            saveButton.disabled = (settings.pass === pass.value && settings.id === id.value && settings.name === nameInput.value);
        }

        if (settings.new) {
            saveButton.disabled = false;
        }
    };

    var localSave = function() {
        localStorage.devices = JSON.stringify(devices);
    };

    var goBack = function() {
        window.location.href = 'index.html#internal';
    };

    var show = function(index) {
        if (localStorage.devices) {
            devices = JSON.parse(localStorage.devices);

            if (devices[index] && !devices[index].new) {
                nameInput.value = devices[index].name;
                id.value = devices[index].id;
                pass.value = devices[index].pass;
                saveButton.disabled = true;
            } else {
                nameInput.value = '';
                id.value = '';
                pass.value = '';
            }
        }
    };

    var deleteSelected = function(button) {
        if (button !== 1) {
            return false;
        }
        devices.splice(selected, 1);
        localSave();
        selected--;
        if (selected < 0) {
            selected = 0;
        }
        updateLists();
        show(selected);
    };

    var saveSelected = function() {
        var settings = {};
        settings.name = nameInput.value;
        settings.id = id.value;
        settings.pass = pass.value;
        devices[selected] = settings;
        delete devices[selected].new;
        localSave();
        updateLists();
    };

    var clearLists = function() {
        var childrenTop = topList.childNodes;
        var childrenBott = bottomList.childNodes;
        while (childrenTop.length > 0) {
            topList.removeChild(childrenTop[0]);
        }
        while (childrenBott.length > 0) {
            bottomList.removeChild(childrenBott[0]);
        }
    };

    var updateLists = function() {
        clearLists();
        if (!localStorage.devices) {
            addComp(true);
            return;
        }
        devices = JSON.parse(localStorage.devices);
        if (devices.length === 0) {
            addComp(true);
            return;
        }
        if (localStorage.pro === 'false') {
            devices.length = 1;
        }
        var device, header, title, icon;

        for (var i = 0; i < devices.length; i++) {
            device = document.createElement('div');
            header = document.createElement('h1');
            icon = document.createElement('span');
            title = devices[i].name || devices[i].id || 'Unnamed';
            if (devices[i].new) {
                title = 'Add new';
            }
            header.appendChild(document.createTextNode(title));
            device.appendChild(header);
            device.appendChild(icon);
            device.className = 'list';
            icon.className = 'list-icon';

            if (i <= selected) {
                topList.appendChild(device);
            } else {
                bottomList.appendChild(device);
            }

            device.addEventListener('click', (function(i) {
                return function() {
                    selected = i;
                    updateLists();
                    show(selected);
                }
            })(i));
        }
    };

    var openPro = function(button) {
        if (button === 1) {
            CDV.WEBINTENT.startActivity({
                    action: CDV.WEBINTENT.ACTION_VIEW,
                    url: 'market://details?id=com.amaan.phonetochromepro'
                },
                function() {

                },
                function() {
                    console.log('Failed to open URL via Android Intent');
                }
            );
        }
    };

    var addComp = function(basic) {
        if (localStorage.pro === 'true' || basic === true) {
            devices.push({
                new: true
            });
            selected = devices.length - 1;;
            localSave();
            updateLists();
            show(selected);
        } else {
            navigator.notification.confirm('This is a pro feature. Do you want to buy Phone to Chrome Pro?', openPro, 'Pro Feature', ['Yes', 'No']);
        }
    };

    var cleanLocal = function() {
        if (!localStorage.devices) {
            return false;
        }
        var rem = [];
        devices = JSON.parse(localStorage.devices);
        for (var i = 0; i < devices.length; i++) {
            if (devices[i].new) {
                rem.push(i);
            }
        }
        for (var i = rem.length - 1; i >= 0; i--) {
            devices.splice(rem[i], 1);
        }
        localSave();
    };

    cleanLocal();
    updateLists();
    back.addEventListener('click', goBack, false);

    nameInput.addEventListener('input', setButtonState, false);
    id.addEventListener('input', setButtonState, false);
    pass.addEventListener('input', setButtonState, false);
    deleteButton.addEventListener('click', function() {
        navigator.notification.confirm(
            'Are you sure you want to delete this computer?',
            deleteSelected,
            '', ['Delete', 'Cancel']
        );
    }, false);

    addComputerButton.addEventListener('click', addComp, false);

    document.addEventListener('backbutton', goBack, false);

    form.addEventListener('submit', function(e) {
        e.preventDefault();
        saveSelected();
        setButtonState();
    }, false);

    form.onsubmit = function() {
	return false;
    };

    show(selected);
})(window);
